@@ -5,7 +5,7 @@ It's a free(libre) software
 """
 from re import *
 import os,sys
-__version__="1.1.3"
+__version__="1.3.1"
 __author__="<Lone_air_Use@outlook.com>"
 import warnings,traceback
 App=None
@@ -38,7 +38,6 @@ Options:
         -o -output *        Compilation results are output to '*' ('*' is a directory name)
         -mode=1|2|3|4       Set the compilation mode
         -install            Install PSML to the directory where Python is located
-        -uninstall          uninstall psml
         -online             Start psml_web
         -u -upgrade         Upgrade psml version
         -cv -check-version  Detect psml version update
@@ -1472,6 +1471,28 @@ def __install__():
     os.system("sh install.sh -quiet")
     return
 
+def vercomp(NEW, OLD):
+    N=NEW.split(".")
+    O=OLD.split(".")
+    l=0
+    lo=len(O)
+    for i in N:
+        l+=1
+        if l>lo:
+            return 1
+        else:
+            try:
+                if int(i)>int(O[l-1]):
+                    return 1
+                elif int(i)<int(O[l-1]):
+                    return 0
+            except:
+                if ord(i.lower())>int(O[l-1].lower()):
+                    return 1
+                elif ord(i.lower())<ord(O[l-1].lower()):
+                    return 0
+    return 0
+
 def upgrade():
     import sys,os,shutil
     VER=_check_ver()
@@ -1492,7 +1513,7 @@ def upgrade():
         except:
             ERR("\033[91mfatal error\033[0m: unable to clone the repository of psml")
             return
-        os.system(sys.executable+" install.sh")
+        os.system("sh install.sh -quiet")
         os.chdir("..")
         while 1:
             try:
@@ -1511,13 +1532,13 @@ def _check_ver():
         ERR("\033[91mfatal error\033[0m: unable to switch working directory to 'temp/'")
         return "ERR"
     import urllib.request, ssl
-    req=urllib.request.Request("https://raw.github.com/Lone-Air/PSML/master/VERSION", headers={"User-Agent": 'Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.5 (like Gecko) (Kubuntu)'})
+    req=urllib.request.Request("https://lone-air.github.io/PSMLVER", headers={"User-Agent": 'Mozilla/5.0 (compatible; Konqueror/3.5; Linux) KHTML/3.5.5 (like Gecko) (Kubuntu)'})
     context=ssl._create_unverified_context()
     try:
         _VER=urllib.request.urlopen(req, context=context)
-        VER=VER.read().decode("utf8")
+        VER=_VER.read().decode("utf8")
         VER=ignore(VER, "\n")
-        if VER==__version__:
+        if not vercomp(VER, __version__):
             print("\033[92mIt's the latest version\033[0m")
             os.chdir("..")
             return "-"
@@ -1526,7 +1547,7 @@ def _check_ver():
             os.chdir("..")
             return VER
     except:
-        print("\033[93mwarning\033[0m: Unable to get the version file from the raw.github.com, git will be used to get the repository to determine the version")
+        print("\033[93mwarning\033[0m: Unable to get the version file from the lone-air.github.io, git will be used to get the repository to determine the version")
         wr_git=find_exe("git")
         if wr_git==[]:
             ERR("\033[91mfatal error\033[0m: git not found")
@@ -1541,7 +1562,7 @@ def _check_ver():
             return "ERR"
         VER=getcont("VERSION")
         VER=ignore(VER, "\n")
-        if VER==__version__:
+        if not vercomp(VER, __version__):
             print("\033[92mIt's the latest edition\033[0m")
             os.chdir("..")
             while 1:
